/////////////////////////////////////////////////////////////////////////////////////////
// Jocopod -- Joystick to Control Port Dongle
//            --          --      --   -
//
// (c) 2015-2016, Oliver "lvr" Tscherwitschke
// lvr@bitbang.de
//
// This file is part of the Jocopod Firmware.
//
// The Jocopod Firmware is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// The Jocopod Firmware is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Jocopod Firmware. If not, see <http://www.gnu.org/licenses/>.
/////////////////////////////////////////////////////////////////////////////////////////

#ifndef MAIN_H
#define MAIN_H


#include "mytypes.h"
#include "config.h"
#include "io.h"


/////////////////////////////////////////////////////////////////
#define FW_VERSION  "0.7"




/////////////////////////////////////////////////////////////////////////////////////////
// Constants

#define T1_SET      ((3 << COM1A0) /* Set OC1A on Compare Match */ \
                   | (3 << COM1B0) /* Set OC1B on Compare Match */ \
                   | (0 << WGM11) \
                   | (0 << WGM10))

#define T1_CLEAR    ((2 << COM1A0) /* Clear OC1A on Compare Match */ \
                   | (2 << COM1B0) /* Clear OC1A on Compare Match */ \
                   | (0 << WGM11) \
                   | (0 << WGM10))

#define T1_START    ((0 << WGM13) \
                   | (0 << WGM12) \
                   | (1 << CS10))  /* Clock source: CLKio/1 (No prescaling) */

#define T1_STOP     ((0 << WGM13) \
                   | (0 << WGM12) \
                   | (0 << CS10))  /* Clock source: No clock source (Timer/Counter stopped) */


#define F_CPU_DIV   (16000000UL / F_CPU)  /* code supports 16 and 8 MHz CPU clock */


#define MAX_VALID_JOY_VALUE     4000

#define LAST_VALID_MODE         MODE_JOY_STICK


/////////////////////////////////////////////////////////////////
// Variables

extern uint8_t operatingMode;
extern Axis axisX;
extern Axis axisY;


/////////////////////////////////////////////////////////////////
// Macros

#define LED1_ON()   do { digitalWrite(DPIN_LED1, HIGH); } while (0)
#define LED1_OFF()  do { digitalWrite(DPIN_LED1, LOW); } while (0)

#define LED2_ON()   do { digitalWrite(DPIN_LED2, LOW); } while (0)
#define LED2_OFF()  do { digitalWrite(DPIN_LED2, HIGH); } while (0)


#endif

